//------------------------------------------------------------
/// \file	Main.cpp
/// \author	Rob Bateman
/// \date	9-feb-2005
/// \brief	This is a really simple example of using glut
///
//------------------------------------------------------------

#include <stdlib.h>
#include <GL/glut.h>
#include "font.h"


/// when we draw the font we really want to draw it in an orthographic
/// projection (like an overlay). This means we need to render the
/// 3D geometry first with a perspective projection, and then render
/// the 2D stuff in an orthographic projection over the top. 
/// 
/// To help, i'm creating 2 display lists, 1 for the ortho projection
/// the other for the perspective projection. These will be created
///	in the rshape function and can then be called to switch modes.
/// 
unsigned int g_persp=0,g_ortho=0;

//------------------------------------------------------------	OnReshape()
void OnReshape(int w, int h)
{
	if (h==0) 
		h=1;

	// delete the last display lists
	glDeleteLists(g_persp,1);
	glDeleteLists(g_ortho,1);

	// set the drawable region of the window
	glViewport(0,0,w,h);

	// generate new display list ID's
	g_persp = glGenLists(1);
	g_ortho = glGenLists(1);

	// generate perspective display list
	glNewList(g_persp,GL_COMPILE);

		// set up the projection matrix 
		glMatrixMode(GL_PROJECTION);
		glLoadIdentity();

		// just use a perspective projection
		gluPerspective(45,(float)w/h,0.1,100);

		// go back to modelview matrix so we can move the objects about
		glMatrixMode(GL_MODELVIEW);
		glLoadIdentity();

	glEndList();


	// generate orthographic display list
	glNewList(g_ortho,GL_COMPILE);

		// set up the projection matrix 
		glMatrixMode(GL_PROJECTION);
		glLoadIdentity();

		// just use a orthographic projection
		glOrtho(0,w,h,0,-100,100);

		// go back to modelview matrix so we can move the objects about
		glMatrixMode(GL_MODELVIEW);
		glLoadIdentity();

	glEndList();
}

//------------------------------------------------------------	OnDraw()
//
void OnDraw() {

	// clear the screen & depth buffer
	glClear(GL_DEPTH_BUFFER_BIT|GL_COLOR_BUFFER_BIT);

	// set the perspective projection
	glCallList(g_persp);

	// set the camera position
	gluLookAt(	1,1,10,	//	eye pos
				0,0,0,	//	aim point
				0,1,0);	//	up direction

	// draw a simple teapot
	glutWireTeapot(1);


	// set the orthographic projection
	glCallList(g_ortho);

	// draw some text
	FontDraw("Hello World",10,24);

	// currently we've been drawing to the back buffer, we need
	// to swap the back buffer with the front one to make the image visible
	glutSwapBuffers();
}

//------------------------------------------------------------	OnInit()
//
void OnInit() {
	// enable depth testing
	glEnable(GL_DEPTH_TEST);
}

//------------------------------------------------------------	OnExit()
//
void OnExit() {
}


//------------------------------------------------------------	main()
//
int main(int argc,char** argv) {

	// initialise glut
	glutInit(&argc,argv);

	// request a depth buffer, RGBA display mode, and we want double buffering
	glutInitDisplayMode(GLUT_DEPTH|GLUT_RGBA|GLUT_DOUBLE);

	// set the initial window size
	glutInitWindowSize(640,480);

	// create the window
	glutCreateWindow("GL Raster Fonts");

	// set the function to use to draw our scene
	glutDisplayFunc(OnDraw);

	// set the function to handle changes in screen size
	glutReshapeFunc(OnReshape);
	
	// run our custom initialisation
	OnInit();

	FontInit();

	// set the function to be called when we exit
	atexit(OnExit);

	// this function runs a while loop to keep the program running.
	glutMainLoop();
	return 0;
}
